@@ -244,7 +244,7 @@ function addBuiltinLibsToObject(object, dummyModuleName) {
   ArrayPrototypeForEach(builtinModules, (name) => {
     // Neither add underscored modules, nor ones that contain slashes (e.g.,
     // 'fs/promises') or ones that are already defined.
-    if (StringPrototypeStartsWith(name, '_') ||
+    if (name[0] === '_' ||
         StringPrototypeIncludes(name, '/') ||
         ObjectPrototypeHasOwnProperty(object, name)) {
       return;
